@@ -98,14 +98,13 @@ def is_admin():
         return False
 
 
-def run_admin(params=''):
+def run_admin():
     '''
     If the python instance does not have admin priviledges, it stops the current execution and runs the program as admin.
     '''
     if not is_admin():
         ctypes.windll.shell32.ShellExecuteW(
-            None, "runas", sys.executable, __file__ + params, None, 1)
-        input()
+            None, "runas", sys.executable, __file__, None, 1)
         sys.exit()
 
 # ------------------------------------------------------------------
